==> haskell-test-framework-0.8.2.0-476-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework
version:              0.8.2.0
visibility:           public
id:                   test-framework-0.8.2.0-6bJyv5QF7GN7YsnZtgrcHk
key:                  test-framework-0.8.2.0-6bJyv5QF7GN7YsnZtgrcHk
license:              BSD-3-Clause
maintainer:           Libraries List <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://haskell.github.io/test-framework/
synopsis:
    Framework for running and organising tests, with HUnit and QuickCheck support

description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.

category:             Testing
abi:                  ec54b8c57d7262ec6cd461f3e2a368a0
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.API Test.Framework.Runners.Console
    Test.Framework.Runners.Options Test.Framework.Runners.TestPattern
    Test.Framework.Seed

hidden-modules:
    Test.Framework.Core Test.Framework.Improving
    Test.Framework.Runners.Console.Colors
    Test.Framework.Runners.Console.ProgressBar
    Test.Framework.Runners.Console.Run
    Test.Framework.Runners.Console.Statistics
    Test.Framework.Runners.Console.Table
    Test.Framework.Runners.Console.Utilities
    Test.Framework.Runners.Core Test.Framework.Runners.Processors
    Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
    Test.Framework.Runners.TimedConsumption
    Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
    Test.Framework.Utilities

import-dirs:          /usr/lib/ghc-9.0.2/site-local/test-framework-0.8.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/test-framework-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework
hs-libraries:         HStest-framework-0.8.2.0-6bJyv5QF7GN7YsnZtgrcHk
depends:
    ansi-terminal-0.11.1-78y8MvYqyGh2ibnhIzekfU
    ansi-wl-pprint-0.6.9-I8vypCNqpid9s7jiSTXJMJ base-4.15.1.0
    containers-0.6.4.1 hostname-1.0-4HkhnKdpx7vFbnzzYgAxYQ
    old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh
    random-1.2.1.1-9D10sZLOM5T93tMINb9MTT
    regex-posix-0.96.0.1-3tnfXrSqQrb7MJMFtuTwG8 time-1.9.3
    xml-1.3.14-6hlhhPBptprHwK7nsE7OzM

haddock-interfaces:
    /usr/share/doc/haskell-test-framework/html/test-framework.haddock

haddock-html:         /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-0.8.2.0-477-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework
version:              0.8.2.0
visibility:           public
id:                   test-framework-0.8.2.0-CpsmCwQLLeK98kPY3HGnq
key:                  test-framework-0.8.2.0-CpsmCwQLLeK98kPY3HGnq
license:              BSD-3-Clause
maintainer:           Libraries List <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://haskell.github.io/test-framework/
synopsis:
    Framework for running and organising tests, with HUnit and QuickCheck support

description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.

category:             Testing
abi:                  a74111c7ea2f856decea5004ce51dc38
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.API Test.Framework.Runners.Console
    Test.Framework.Runners.Options Test.Framework.Runners.TestPattern
    Test.Framework.Seed

hidden-modules:
    Test.Framework.Core Test.Framework.Improving
    Test.Framework.Runners.Console.Colors
    Test.Framework.Runners.Console.ProgressBar
    Test.Framework.Runners.Console.Run
    Test.Framework.Runners.Console.Statistics
    Test.Framework.Runners.Console.Table
    Test.Framework.Runners.Console.Utilities
    Test.Framework.Runners.Core Test.Framework.Runners.Processors
    Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
    Test.Framework.Runners.TimedConsumption
    Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
    Test.Framework.Utilities

import-dirs:          /usr/lib/ghc-9.0.2/site-local/test-framework-0.8.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/test-framework-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework
hs-libraries:         HStest-framework-0.8.2.0-CpsmCwQLLeK98kPY3HGnq
depends:
    ansi-terminal-0.11.1-DQExpzflmhRACMvBvKWkVz
    ansi-wl-pprint-0.6.9-4MRC6jDqVV95sepe6KHwkj base-4.15.1.0
    containers-0.6.4.1 hostname-1.0-4HkhnKdpx7vFbnzzYgAxYQ
    old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh
    random-1.2.1.1-7hIjssL3s0vKltA9rBNATF
    regex-posix-0.96.0.1-3tnfXrSqQrb7MJMFtuTwG8 time-1.9.3
    xml-1.3.14-6hlhhPBptprHwK7nsE7OzM

haddock-interfaces:
    /usr/share/doc/haskell-test-framework/html/test-framework.haddock

haddock-html:         /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
